# Python Client Library for Foxglove

[![foxglove-client on PyPI](https://img.shields.io/pypi/v/foxglove-client?label=pypi%20%7C%20foxglove-client)](https://pypi.org/project/foxglove-client/)

This library provides a convenient python client for [Foxglove](https://foxglove.dev/).

In order to use the client you will first have to create an API token for your organization on your organization's [settings page](https://app.foxglove.dev/~/settings).

Read more about the API in the [Foxglove API Docs](https://docs.foxglove.dev/api/).

## Sample Usage

Examples of various client features can be found in the `examples` directory.

## Running Tests

```bash
pipenv install --dev
pipenv run python -m pytest
```

## Stay in touch

Join our [Discord](https://foxglove.dev/chat) to ask questions, share feedback, and stay up to date on what our team is working on.
